@@ -1,4 +1,4 @@
-from typing import Any
+from typing import Any, Type
 
 from faust.serializers import codecs
 from schema_registry.client import SchemaRegistryClient
@@ -8,7 +8,7 @@ from aiodeu.config import Config
 
 
 class AvroJsonCodec(codecs.Codec):
-    def __init__(self, *args, config: Config = Config, **kwargs: Any) -> None:
+    def __init__(self, *args, config: Type[Config] = Config, **kwargs: Any) -> None:
         self.config = config
         self.client = SchemaRegistryClient(self.config.AVRO_SCHEMA_REGISTRY)
         self.message_serializer = AvroMessageSerializer(self.client)
