@@ -7,7 +7,7 @@ try:
 except ImportError:
     # Got to provide this function. Otherwise, poetry will fail
     def build(setup_kwargs):
-        pass
+        print("-------NOT CYTHONIZING---------")
 # Cython is installed. Compile
 else:
     from setuptools import Extension
@@ -17,6 +17,7 @@ else:
     # This function will be executed in setup.py:
     def build(setup_kwargs):
         # The file you want to compile
+        print("-------CYTHONIZING---------")
         extensions = [
             "aiodeu/cetl.pyx"
         ]
